@@ -44,21 +44,13 @@ class WorkerConnection(Protocol):
         self._read_buffer = b''
 
     def connectionMade(self):
-        if self.factory.proxy.task_dispatcher.reloading:
-            # 如果当前正处于运行状态，那么就应该放到ready_workers列表里去
-            self.factory.proxy.task_dispatcher.add_ready_worker(self)
-        else:
-            # 建立连接就直接去申请task
-            self.alloc_task()
+        # 建立连接就直接去申请task
+        self.alloc_task()
 
     def connectionLost(self, reason=connectionDone):
         # 要删除掉对应的worker
         self.factory.proxy.task_dispatcher.remove_worker(self)
 
-        if self.factory.proxy.task_dispatcher.reloading:
-            # 如果当前正处于运行状态，那么还应该去尝试一下删除
-            self.factory.proxy.task_dispatcher.remove_ready_worker(self)
-
     def dataReceived(self, data):
         """
         当数据接受到时
